@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.1-or-later
 */
@@ -13,7 +13,7 @@
 #include <KConfigGroup>
 #include <KDirWatch>
 #include <KLocalizedString>
-#include <KNS3/QtQuickDialogWrapper>
+#include <KNSWidgets/Action>
 #include <KSharedConfig>
 #include <KToggleAction>
 #include <QAction>
@@ -39,16 +39,12 @@ public:
         watch = new KDirWatch(q);
         initThemesDirectories(relativePath);
         if (KAuthorized::authorize(QStringLiteral("ghns"))) {
-            downloadThemesAction = new QAction(i18n("Download New Themes..."), q);
-            downloadThemesAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+            downloadThemesAction = new KNSWidgets::Action(i18n("Download new Templates..."), QString(), q);
             if (actionCollection) {
                 actionCollection->addAction(QStringLiteral("download_header_themes"), downloadThemesAction);
             }
             separatorAction = new QAction(q);
             separatorAction->setSeparator(true);
-            q->connect(downloadThemesAction, &QAction::triggered, q, [this]() {
-                slotDownloadHeaderThemes();
-            });
         }
 
         q->connect(watch, &KDirWatch::dirty, q, [this]() {
@@ -77,11 +73,6 @@ public:
         themes.clear();
     }
 
-    void slotDownloadHeaderThemes()
-    {
-        KNS3::QtQuickDialogWrapper(downloadConfigFileName).exec();
-    }
-
     void directoryChanged()
     {
         updateThemesPath();
@@ -152,7 +143,9 @@ public:
         }
         if (separatorAction) {
             menu->removeAction(separatorAction);
-            menu->removeAction(downloadThemesAction);
+            if (downloadThemesAction) {
+                menu->removeAction(downloadThemesAction);
+            }
         }
         themesActionList.clear();
     }
@@ -200,7 +193,9 @@ public:
         }
         if (separatorAction) {
             menu->addAction(separatorAction);
-            menu->addAction(downloadThemesAction);
+            if (downloadThemesAction) {
+                menu->addAction(downloadThemesAction);
+            }
         }
     }
 
@@ -251,7 +246,6 @@ public:
 
     QString applicationType;
     QString defaultDesktopFileName;
-    QString downloadConfigFileName;
     QStringList themesDirectories;
     QMap<QString, GrantleeTheme::Theme> themes;
     QVector<KToggleAction *> themesActionList;
@@ -260,8 +254,7 @@ public:
     KActionMenu *menu = nullptr;
     KActionCollection *const actionCollection;
     QAction *separatorAction = nullptr;
-
-    QAction *downloadThemesAction = nullptr;
+    KNSWidgets::Action *downloadThemesAction = nullptr;
     ThemeManager *const q;
 };
 }
@@ -326,7 +319,9 @@ GrantleeTheme::Theme ThemeManager::theme(const QString &themeName)
 
 void ThemeManager::setDownloadNewStuffConfigFile(const QString &configFileName)
 {
-    d->downloadConfigFileName = configFileName;
+    if (d->downloadThemesAction) {
+        d->downloadThemesAction->setConfigFile(configFileName);
+    }
 }
 
 QString ThemeManager::pathFromThemes(const QString &themesRelativePath, const QString &themeName, const QString &defaultDesktopFileName)
